pub comptime fn internal(f: FunctionDefinition)
Internal functions can only be called by the contract itself, typically from private into public.
Internal functions can only be called by the contract itself, typically from private into public.