pub comptime fn public(f: FunctionDefinition) -> Quoted
Public functions are executed sequencer-side and do not preserve privacy, similar to the EVM.
Public functions are executed sequencer-side and do not preserve privacy, similar to the EVM.