Utility functions are standalone unconstrained functions that cannot be called from another function in a contract.
They are typically used either to obtain some information from the contract (e.g. token balance of a user) or to
modify internal contract-related state of PXE (e.g. processing logs in Aztec.nr during sync).
Utility functions are standalone unconstrained functions that cannot be called from another function in a contract. They are typically used either to obtain some information from the contract (e.g. token balance of a user) or to modify internal contract-related state of PXE (e.g. processing logs in Aztec.nr during sync).